@@ -9,18 +9,10 @@ from __future__ import absolute_import
 
 import os
 import os.path
-from raven.base import *  # NOQA
-from raven.conf import *  # NOQA
-from raven.versioning import *  # NOQA
-
 
 __all__ = ('VERSION', 'Client', 'get_version')
 
-try:
-    VERSION = __import__('pkg_resources') \
-        .get_distribution('raven').version
-except Exception as e:
-    VERSION = 'unknown'
+VERSION = '5.25.0'
 
 
 def _get_git_revision(path):
@@ -55,3 +47,9 @@ def get_version():
 
 __build__ = get_revision()
 __docformat__ = 'restructuredtext en'
+
+
+# Declare child imports last to prevent recursion
+from raven.base import *  # NOQA
+from raven.conf import *  # NOQA
+from raven.versioning import *  # NOQA
